# Table of Contents

- [Table of Contents](#table-of-contents)
- [About](#about)
  - [Operating System Support](#operating-system-support)
  - [Python Version Support](#python-version-support)

# About

`ni-grpc-extensions` is a Python package that provides channel pool handling for gRPC communication.

NI created and supports this package.

## Operating System Support

``ni-grpc-extensions` supports Windows and Linux operating systems.

## Python Version Support

``ni-grpc-extensions` supports CPython 3.9+.
